/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ReferenceHelper.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.builder.webserviceref;

import javax.naming.RefAddr;
import javax.naming.Reference;
import javax.naming.StringRefAddr;

/**
 * A ReferenceHelper is a class that helps to insert and extracts values
 * in and out of a JNDI Reference.
 * @author Guillaume Sauthier
 */
public class ReferenceHelper {

    /**
     * Wrapped reference.
     */
    private Reference reference;

    /**
     * Creates a helper dedicated to the given Reference.
     * @param reference wrapped Reference
     */
    public ReferenceHelper(final Reference reference) {
        this.reference = reference;
    }

    /**
     * Insert into the wrapped Reference the given key/value String pair.
     * @param key the unique key
     * @param value the String value
     * @return this helper for chained invocation.
     */
    public ReferenceHelper insert(final String key, final String value) {
        // Only insert something if the value is not null
        if (value != null) {
            reference.add(new StringRefAddr(key, value));
        }
        return this;
    }

    /**
     * Extract a value from the wrapped Reference using the given key.
     * @param key the key
     * @return the String value or null if the key was not referring to a
     *         StringRefAddr or if the key was not found in the Reference
     */
    public String extract(final String key) {
        RefAddr addr = reference.get(key);
        if ((addr != null) && (addr instanceof StringRefAddr)) {
            StringRefAddr sra = (StringRefAddr) addr;
            return (String) sra.getContent();
        }
        return null;
    }
}
